# List Node
DATA_NAME = "data"
NEXT_NAME = "next"
PREV_NAME = "prev"

# Printer
FORWARD_LINK = " ─> "
BACKWARD_LINK = " <─ "
BIDIRECTION_LINK = " <─> "
